Description Usage Arguments Value
First, seeds the random number generator with seed. Then generates
a sequence of n random integers between 1 and
.Machine$integer.max. Finally, seeds the random number generator
with the nth (i.e. last) number in this sequence. The point of this
function is that it may be used to seed the RNG at the start of a job
that is run on a cluster, so that parallel jobs are using – if not
statistically independent random number streams – at least not the exact
same stream.
1 |
n |
Number (e.g. id of parallel job) |
seed |
Initial seed; this should be set so that results are replicable |
... |
Further parameters passed to |
The final seed, i.e. the nth number in the sequence
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.